@@ -141,7 +141,7 @@
 
 namespace eval ::DES {
 
-  variable version 0.8.1
+  variable version 0.8.2
 
   namespace export GetKey DesBlock
 
@@ -411,7 +411,7 @@ namespace eval ::DES {
      
       for { set j  0 } { $j < 56 } { incr j } {
           set l $pc1($j)
-          set m [expr $l & 07]
+          set m [expr {$l & 07}]
           if {$useVNC} {
               set pc1m($j) [expr { ( ($keyBlock([expr {$l >> 3}]) & $bytebitVNC($m)) != 0 ) ? 1: 0 }]
           } else {
@@ -421,7 +421,7 @@ namespace eval ::DES {
       for { set i 0 } { $i < 16 } { incr i } {
 
           set m [expr { $encDec ? ($i << 1) : ((15-$i) << 1) }]
-          set n [expr $m + 1]
+          set n [expr {$m + 1}]
           set kn($m) 0 
           set kn($n) 0
           for { set j 0 } { $j < 28 } { incr j } {
@@ -445,7 +445,7 @@ namespace eval ::DES {
               if {$pcr($pc2($j)) != 0} { 
                   set kn($m) [expr { $kn($m) | $bigbyte($j) }] 
               }
-              if {$pcr($pc2([expr $j+24])) != 0} {
+              if {$pcr($pc2([expr {$j+24}])) != 0} {
                   set kn($n) [expr { $kn($n) | $bigbyte($j) }]
               }
           }
