@@ -385,9 +385,9 @@ proc ::doctools::toc::_format {name text} {
 	    # Filter for checker errors and reduce them to the essential message.
 
 	    if {![regexp {^Error in} $msg]}          {return -code error $msg}
-	    set msg [join [lrange [split $msg \n] 2 end]]
+	    #set msg [join [lrange [split $msg \n] 2 end]]
 
-	    if {![regexp {^--> \(FmtError\) } $msg]} {return -code error @$msg}
+	    if {![regexp {^--> \(FmtError\) } $msg]} {return -code error "Doctoc $msg"}
 	    set msg [lindex [split $msg \n] 0]
 	    regsub {^--> \(FmtError\) } $msg {} msg
 
@@ -902,4 +902,4 @@ namespace eval ::doctools::toc {
     catch {search [file join $here                             mpformats]}
 }
 
-package provide doctools::toc 0.1
+package provide doctools::toc 0.2
