@@ -7,7 +7,7 @@
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 # 
-# RCS: @(#) $Id$
+# RCS: @(#) $Id: doctools.tcl,v 1.10 2004/05/26 04:24:28 andreas_kupries Exp $
 
 package require Tcl 8.2
 package require textutil::expander
@@ -107,6 +107,7 @@ proc ::doctools::help {} {
 	    * require       - package requirement\n\
 	    * description   - begin of manpage body\n\
 	    * section       - begin new section of body\n\
+	    * subsection    - begin new sub-section of body\n\
 	    * para          - begin new paragraph\n\
 	    * list_begin    - begin a list\n\
 	    * list_end      - end of a list\n\
@@ -132,6 +133,7 @@ proc ::doctools::help {} {
 	    * sectref       - semantic markup - section reference\n\
 	    * syscmd        - semantic markup - system command\n\
 	    * method        - semantic markup - object method\n\
+	    * namespace     - semantic markup - namespace name\n\
 	    * option        - semantic markup - option\n\
 	    * widget        - semantic markup - widget\n\
 	    * fun           - semantic markup - function\n\
@@ -140,7 +142,7 @@ proc ::doctools::help {} {
 	    * class         - semantic markup - class\n\
 	    * var           - semantic markup - variable\n\
 	    * file          - semantic markup - file \n\
-	    * uri           - semantic markup - uri\n\
+	    * uri           - semantic markup - uri (optional label)\n\
 	    * term          - semantic markup - unspecific terminology\n\
 	    * const         - semantic markup - constant value\n\
 	    * emph          - emphasis\n\
@@ -470,9 +472,9 @@ proc ::doctools::_format {name text} {
 	    # Filter for checker errors and reduce them to the essential message.
 
 	    if {![regexp {^Error in} $msg]}          {return -code error $msg}
-	    set msg [join [lrange [split $msg \n] 2 end]]
+	    #set msg [join [lrange [split $msg \n] 2 end]]
 
-	    if {![regexp {^--> \(FmtError\) } $msg]} {return -code error @$msg}
+	    if {![regexp {^--> \(FmtError\) } $msg]} {return -code error "Doctools $msg"}
 	    set msg [lindex [split $msg \n] 0]
 	    regsub {^--> \(FmtError\) } $msg {} msg
 
@@ -778,6 +780,7 @@ proc ::doctools::SetupChecker {name} {
 	keywords nl arg cmd opt comment sectref syscmd method option
 	widget fun type package class var file uri usage term const
 	arg_def cmd_def opt_def tkoption_def emph strong plain_text
+	namespace subsection
     } {
 	interp alias $chk_ip fmt_$cmd $format_ip fmt_$cmd
     }
@@ -896,6 +899,15 @@ proc ::doctools::Eval {name macro} {
 	return [ExpandInclude $name $filename]
     }
 
+    # Rewrite the [namespace] command before passing it on.
+    # "namespace" is a special command. The interpreter the validator
+    # resides in uses the package "msgcat", which in turn uses the
+    # builtin namespace. So the builtin cannot be simply
+    # overwritten. We use a different name.
+
+    if {[string match namespace* $macro]} {
+	set macro _$macro
+    }
     return [$chk_ip eval $macro]
 }
 
@@ -1156,4 +1168,4 @@ namespace eval ::doctools {
     catch {search [file join $here                             mpformats]}
 }
 
-package provide doctools 1.0.2
+package provide doctools 1.1
