@@ -697,3 +697,13 @@ proc ::struct::pool::request {poolname itemvar args} {
 
 
 # EOF pool.tcl
+
+# ### ### ### ######### ######### #########
+## Ready
+
+namespace eval ::struct {
+    # Get 'pool::pool' into the general structure namespace.
+    namespace import -force pool::pool
+    namespace export pool
+}
+package provide struct::pool 1.2.1
