@@ -19,8 +19,14 @@ proc tclfiles {} {
     global distribution
     package require fileutil
     set fl [fileutil::findByPattern $distribution -glob *.tcl]
-    proc tclfiles {} [list return $fl]
-    return $fl
+    # Remove files under SCCS. They are repository, not sources to check.
+    set tmp {}
+    foreach f $fl {
+	if {[string match *SCCS* $f]} continue
+	lappend tmp $f
+    }
+    proc tclfiles {} [list return $tmp]
+    return $tmp
 }
 
 proc modtclfiles {modules} {
@@ -30,7 +36,13 @@ proc modtclfiles {modules} {
     foreach m $modules {
 	eval $guide($m,pkg) $m __dummy__
     }
-    return $mfiles
+    set tmp {}
+    foreach f $mfiles {
+	if {[string match *SCCS* $f]} continue
+	lappend tmp $f
+    }
+
+    return $tmp
 }
 
 
@@ -197,29 +209,27 @@ proc gendoc {fmt ext args} {
     if {![string compare $fmt null]} {set null 1}
     if {[llength $args] == 0} {set args [modules]}
 
-    set mpe [file join $distribution modules doctools mpexpand]
-    if {$tcl_platform(platform) != "unix"} {
-        set mpe [list [info nameofexecutable] $mpe]
-    }
-    set ::env(TCLLIBPATH) [file join $distribution modules]
-
     if {!$null} {
 	file mkdir [file join doc $fmt]
     }
 
-    foreach m $args {
-	set fl [glob -nocomplain [file join $distribution modules $m *.man]]
-	if {[llength $fl] == 0} {continue}
+    #package require doctools
+    if {[catch {package present doctools}]} {
+	uplevel #0 [list source [file join $distribution modules doctools doctools.tcl]]
+    }
 
-	if {$null} {
-	    set tmp    [open [set tmpname [file rootname [info script]].tmp.[pid]] w]
-	    set target -
-	    set stdout $tmp
-	    set stderr $tmp
-	} else {
-	    set stdout stdout
-	    set stderr stderr
+    foreach m $args {
+	::doctools::new dt \
+		-format $fmt \
+		-module $m
+
+	set fl [glob -nocomplain [file join $distribution modules $m *.man]]
+
+	if {[llength $fl] == 0} {
+	    dt destroy
+	    continue
 	}
+
 	foreach f $fl {
 	    if {!$null} {
                 set target [file join doc $fmt \
@@ -231,20 +241,28 @@ proc gendoc {fmt ext args} {
 	    }
 	    puts "Gen ($fmt): $f"
 
-	    set     cmd $mpe
-	    lappend cmd -module $m
-	    if {$null} {lappend cmd -deprecated}
-	    lappend cmd $fmt $f $target >@ $stdout 2>@ $stderr
+	    dt configure -file $f
+	    if {$null} {
+		dt configure -deprecated 1
+	    }
+
 	    if {[catch {
-		eval exec $cmd
+		set data [dt format [get_input $f]]
 	    } msg]} {
 		puts $msg
+		continue
+	    }
+
+	    set warnings [dt warnings]
+	    if {[llength $warnings] > 0} {
+		puts stderr [join $warnings \n]
+	    }
+
+	    if {!$null} {
+		write_out $target $data
 	    }
 	}
-	if {$null} {
-	    catch {close $tmp}
-	    catch {file delete -force $tmpname}
-	}
+	dt destroy
     }
 }
 
@@ -471,7 +489,7 @@ proc gd-gen-tap {} {
 proc gd-gen-rpmspec {} {
     global tcllib_version tcllib_name distribution
 
-    set header [string map [list @@@@ $tcllib_version @__@ $tcllib_name] {# $Id: sak.tcl,v 1.26 2004/04/16 09:32:36 patthoyts Exp $
+    set header [string map [list @@@@ $tcllib_version @__@ $tcllib_name] {# $Id: sak.tcl,v 1.31 2004/07/12 00:06:02 patthoyts Exp $
 
 %define version @@@@
 %define directory /usr
@@ -573,9 +591,11 @@ proc docfiles {} {
     package require fileutil
     set res [list]
     foreach f [fileutil::findByPattern $distribution -glob *.man] {
+	# Remove files under SCCS. They are repository, not sources to check.
+	if {[string match *SCCS* $f]} continue
 	lappend res [file rootname [file tail $f]].n
     }
-    proc tclfiles {} [list return $res]
+    proc docfiles {} [list return $res]
     return $res
 }
 
@@ -830,6 +850,24 @@ proc run-procheck {args} {
 
 proc get_input {f} {return [read [set if [open $f r]]][close $if]}
 
+proc write_out {f text} {
+    catch {file delete -force $f}
+    puts -nonewline [set of [open $f w]] $text
+    close $of
+}
+
+proc write_out {f text} {
+    catch {file delete -force $f}
+    puts -nonewline [set of [open $f w]] $text
+    close $of
+}
+
+proc write_out {f text} {
+    catch {file delete -force $f}
+    puts -nonewline [set of [open $f w]] $text
+    close $of
+}
+
 
 proc gd-gen-packages {} {
     global tcllib_version distribution
@@ -1158,6 +1196,8 @@ array set critclmodules {
     md4c      md4/md4c.tcl
     md5c      md5/md5c.tcl
     md5cryptc md5crypt/md5cryptc.tcl
+    rc4c      rc4/rc4c.tcl
+    uuid      uuid/uuid.tcl
 }
 
 # Build critcl modules. If no args then build the tcllibc module.
